@@ -15,13 +15,13 @@ from flaky import flaky
 from ipykernel.serialize import serialize_object
 from pygments.token import Name
 import pytest
-from qtpy import PYQT5, PYQT_VERSION
+from qtpy import PYQT4, PYQT5, PYQT_VERSION
 from qtpy.QtCore import Qt, QTimer
 from qtpy.QtWidgets import QApplication
 
 from spyder.config.gui import get_color_scheme
 from spyder.config.main import CONF
-from spyder.py3compat import PY2
+from spyder.py3compat import PY2, PY3
 from spyder.plugins.ipythonconsole import (IPythonConsole,
                                            KernelConnectionDialog)
 from spyder.utils.environ import listdict2envdict
@@ -64,7 +64,10 @@ def get_console_background_color(style_sheet):
 #==============================================================================
 @pytest.fixture
 def ipyconsole(request):
-    console = IPythonConsole(None, testing=True)
+    try:
+        console = IPythonConsole(None, testing=True, test_dir=request.param)
+    except AttributeError:
+        console = IPythonConsole(None, testing=True)
     console.create_new_client()
     def close_console():
         console.closing_plugin()
@@ -77,7 +80,30 @@ def ipyconsole(request):
 #==============================================================================
 # Tests
 #==============================================================================
+@pytest.mark.parametrize('ipyconsole', [osp.join(TEMP_DIRECTORY, u'測試',
+                                                 u'اختبار')], indirect=True)
+@pytest.mark.skipif(os.name == 'nt', reason="It times out sometimes on Windows")
+def test_console_stderr_file(ipyconsole, qtbot):
+    """Test a the creation of a console with a stderr file in ascii dir."""
+    # Wait until the window is fully up
+    shell = ipyconsole.get_current_shellwidget()
+    qtbot.waitUntil(lambda: shell._prompt_html is not None,
+                    timeout=SHELL_TIMEOUT)
+
+    # Create a new client with s stderr file in a non-ascii dir
+    ipyconsole.create_new_client()
+    shell = ipyconsole.get_current_shellwidget()
+    qtbot.waitUntil(lambda: shell._prompt_html is not None,
+                    timeout=SHELL_TIMEOUT)
+    with qtbot.waitSignal(shell.executed):
+        shell.execute('a = 1')
+
+    # Assert we get the a value correctly
+    assert shell.get_value('a') == 1
+
+
 @flaky(max_runs=3)
+@pytest.mark.skipif(os.name == 'nt', reason="It times out sometimes on Windows")
 def test_console_import_namespace(ipyconsole, qtbot):
     """Test an import of the form 'from foo import *'."""
     # Wait until the window is fully up
@@ -210,7 +236,7 @@ def test_get_syspath(ipyconsole, qtbot):
         pass
 
 
-@flaky(max_runs=3)
+@flaky(max_runs=10)
 @pytest.mark.skipif(os.name == 'nt', reason="It doesn't work on Windows")
 def test_browse_history_dbg(ipyconsole, qtbot):
     """Test that browsing command history is working while debugging."""
@@ -284,8 +310,9 @@ def test_read_stderr(ipyconsole, qtbot):
     assert content == client._read_stderr()
 
 
-@flaky(max_runs=3)
-@pytest.mark.skipif(True, reason="It times out too much (to check later)")
+@flaky(max_runs=10)
+@pytest.mark.skipif(os.environ.get('CI', None) is not None,
+                    reason="It times out in our CIs")
 def test_values_dbg(ipyconsole, qtbot):
     """
     Test that getting, setting, copying and removing values is working while
@@ -302,7 +329,7 @@ def test_values_dbg(ipyconsole, qtbot):
     with qtbot.waitSignal(shell.executed):
         shell.execute('1/0')
     shell.execute('%debug')
-    qtbot.wait(500)
+    qtbot.wait(1000)
 
     # Get value
     qtbot.keyClicks(control, '!aa = 10')
@@ -329,7 +356,7 @@ def test_values_dbg(ipyconsole, qtbot):
     assert "*** NameError: name 'aa' is not defined" in control.toPlainText()
 
 
-@flaky(max_runs=3)
+@flaky(max_runs=10)
 @pytest.mark.skipif(os.name == 'nt', reason="It doesn't work on Windows")
 def test_plot_magic_dbg(ipyconsole, qtbot):
     """Test our plot magic while debugging"""
@@ -348,7 +375,7 @@ def test_plot_magic_dbg(ipyconsole, qtbot):
     with qtbot.waitSignal(shell.executed):
         shell.execute('1/0')
     shell.execute('%debug')
-    qtbot.wait(500)
+    qtbot.wait(1000)
 
     # Test reset magic
     qtbot.keyClicks(control, '%plot plt.plot(range(10))')
@@ -426,8 +453,8 @@ def test_mpl_backend_change(ipyconsole, qtbot):
     assert shell._control.toHtml().count('img src') == 1
 
 
-@flaky(max_runs=3)
-@pytest.mark.skipif(os.name == 'nt', reason="It times out on Windows")
+@flaky(max_runs=10)
+@pytest.mark.skipif(PYQT5, reason="It times out frequently in PyQt5")
 def test_ctrl_c_dbg(ipyconsole, qtbot):
     """
     Test that Ctrl+C works while debugging
@@ -444,15 +471,15 @@ def test_ctrl_c_dbg(ipyconsole, qtbot):
         shell.execute('1/0')
 
     shell.execute('%debug')
-    qtbot.wait(500)
+    qtbot.wait(1000)
 
     # Test Ctrl+C
     qtbot.keyClick(control, Qt.Key_C, modifier=Qt.ControlModifier)
-    qtbot.wait(500)
+    qtbot.wait(2000)
     assert 'For copying text while debugging, use Ctrl+Shift+C' in control.toPlainText()
 
 
-@flaky(max_runs=3)
+@flaky(max_runs=10)
 @pytest.mark.skipif(os.name == 'nt', reason="It doesn't work on Windows")
 def test_clear_and_reset_magics_dbg(ipyconsole, qtbot):
     """
@@ -470,7 +497,7 @@ def test_clear_and_reset_magics_dbg(ipyconsole, qtbot):
         shell.execute('1/0')
 
     shell.execute('%debug')
-    qtbot.wait(500)
+    qtbot.wait(1000)
 
     # Test clear magic
     shell.clear_console()
@@ -563,7 +590,8 @@ def test_load_kernel_file_from_location(ipyconsole, qtbot):
 
 
 @flaky(max_runs=3)
-@pytest.mark.skipif(os.name == 'nt', reason="It times out on Windows")
+@pytest.mark.skipif(os.name == 'nt' or (PY3 and PYQT4),
+                    reason="It segfaults frequently")
 def test_load_kernel_file(ipyconsole, qtbot):
     """
     Test that a new client is created using the connection file
